@@ -1,6 +1,6 @@
 /*============================================================================
-  WCSLIB 8.2 - an implementation of the FITS WCS standard.
-  Copyright (C) 1995-2023, Mark Calabretta
+  WCSLIB 8.3 - an implementation of the FITS WCS standard.
+  Copyright (C) 1995-2024, Mark Calabretta
 
   This file is part of WCSLIB.
 
@@ -19,7 +19,7 @@
 
   Author: Mark Calabretta, Australia Telescope National Facility, CSIRO.
   http://www.atnf.csiro.au/people/Mark.Calabretta
-  $Id: lin_f.c,v 8.2.1.1 2023/11/16 10:05:58 mcalabre Exp mcalabre $
+  $Id: lin_f.c,v 8.3 2024/05/13 16:33:01 mcalabre Exp $
 *===========================================================================*/
 
 #include <stdio.h>
@@ -46,6 +46,7 @@
 #define lincpy_  F77_FUNC(lincpy,  LINCPY)
 #define linfree_ F77_FUNC(linfree, LINFREE)
 #define linsize_ F77_FUNC(linsize, LINSIZE)
+#define linenq_  F77_FUNC(linenq,  LINENQ)
 #define linprt_  F77_FUNC(linprt,  LINPRT)
 #define linperr_ F77_FUNC(linperr, LINPERR)
 #define linset_  F77_FUNC(linset,  LINSET)
@@ -53,6 +54,11 @@
 #define linx2p_  F77_FUNC(linx2p,  LINX2P)
 #define linwarp_ F77_FUNC(linwarp, LINWARP)
 
+#ifdef BINDC
+  #undef  linperr_
+  #define linperr_ linperr_c
+#endif
+
 // Must match the values set in lin.inc.
 #define LIN_FLAG   100
 #define LIN_NAXIS  101
@@ -80,27 +86,27 @@ int linput_(
   const int *j)
 
 {
-  int i0, j0, k, status = 0;
-  const int *ivalp;
-  const double *dvalp;
-  struct linprm *linp;
-
   // Cast pointers.
-  linp  = (struct linprm *)lin;
-  ivalp = (const int *)value;
-  dvalp = (const double *)value;
+  struct linprm *linp = (struct linprm *)lin;
+  const int    *ivalp = (const int *)value;
+  const double *dvalp = (const double *)value;
 
   // Convert 1-relative FITS axis numbers to 0-relative C array indices.
-  i0 = *i - 1;
-  j0 = *j - 1;
+  int i0 = *i - 1;
+  int j0 = *j - 1;
 
+  // Preserve bypass mode.
+  int flag = 0;
+  if (linp->flag == 1 || linp->flag < 0) flag = 1;
+
+  int k, status = 0;
   switch (*what) {
   case LIN_FLAG:
     linp->flag = *ivalp;
     break;
   case LIN_NAXIS:
     linp->naxis = *ivalp;
-    linp->flag = 0;
+    linp->flag = flag;
     break;
   case LIN_CRPIX:
     linp->crpix[i0] = *dvalp;
@@ -108,21 +114,21 @@ int linput_(
   case LIN_PC:
     k = (i0)*(linp->naxis) + (j0);
     *(linp->pc+k) = *dvalp;
-    linp->flag = 0;
+    linp->flag = flag;
     break;
   case LIN_CDELT:
     linp->cdelt[i0] = *dvalp;
-    linp->flag = 0;
+    linp->flag = flag;
     break;
   case LIN_DISPRE:
     // N.B. value is the address of an allocated disprm struct.
     status = lindis(1, linp, (struct disprm *)value);
-    linp->flag = 0;
+    linp->flag = flag;
     break;
   case LIN_DISSEQ:
     // N.B. value is the address of an allocated disprm struct.
     status = lindis(2, linp, (struct disprm *)value);
-    linp->flag = 0;
+    linp->flag = flag;
     break;
   default:
     return 1;
@@ -148,22 +154,13 @@ int linpti_(int *lin, const int *what, const int *value,
 int linget_(const int *lin, const int *what, void *value)
 
 {
-  unsigned int l;
-  int i, j, naxis;
-  int *ivalp;
-  double *dvalp;
-  struct disprm **disvalp;
-  const int *ilinp;
-  const double *dlinp;
-  const struct linprm *linp;
-
   // Cast pointers.
-  linp  = (const struct linprm *)lin;
-  ivalp = (int *)value;
-  dvalp = (double *)value;
-  disvalp = (struct disprm **)value;
+  const struct linprm *linp  = (const struct linprm *)lin;
+  int    *ivalp = (int *)value;
+  double *dvalp = (double *)value;
+  struct disprm **disvalp = (struct disprm **)value;
 
-  naxis = linp->naxis;
+  int naxis = linp->naxis;
 
   switch (*what) {
   case LIN_FLAG:
@@ -173,22 +170,22 @@ int linget_(const int *lin, const int *what, void *value)
     *ivalp = naxis;
     break;
   case LIN_CRPIX:
-    for (i = 0; i < naxis; i++) {
+    for (int i = 0; i < naxis; i++) {
       *(dvalp++) = linp->crpix[i];
     }
     break;
   case LIN_PC:
     // C row-major to FORTRAN column-major.
-    for (j = 0; j < naxis; j++) {
-      dlinp = linp->pc + j;
-      for (i = 0; i < naxis; i++) {
+    for (int j = 0; j < naxis; j++) {
+      const double *dlinp = linp->pc + j;
+      for (int i = 0; i < naxis; i++) {
         *(dvalp++) = *dlinp;
         dlinp += naxis;
       }
     }
     break;
   case LIN_CDELT:
-    for (i = 0; i < naxis; i++) {
+    for (int i = 0; i < naxis; i++) {
       *(dvalp++) = linp->cdelt[i];
     }
     break;
@@ -202,9 +199,9 @@ int linget_(const int *lin, const int *what, void *value)
     break;
   case LIN_PIXIMG:
     // C row-major to FORTRAN column-major.
-    for (j = 0; j < naxis; j++) {
-      dlinp = linp->piximg + j;
-      for (i = 0; i < naxis; i++) {
+    for (int j = 0; j < naxis; j++) {
+      const double *dlinp = linp->piximg + j;
+      for (int i = 0; i < naxis; i++) {
         *(dvalp++) = *dlinp;
         dlinp += naxis;
       }
@@ -212,9 +209,9 @@ int linget_(const int *lin, const int *what, void *value)
     break;
   case LIN_IMGPIX:
     // C row-major to FORTRAN column-major.
-    for (j = 0; j < naxis; j++) {
-      dlinp = linp->imgpix + j;
-      for (i = 0; i < naxis; i++) {
+    for (int j = 0; j < naxis; j++) {
+      const double *dlinp = linp->imgpix + j;
+      for (int i = 0; i < naxis; i++) {
         *(dvalp++) = *dlinp;
         dlinp += naxis;
       }
@@ -235,12 +232,12 @@ int linget_(const int *lin, const int *what, void *value)
   case LIN_ERR:
     // Copy the contents of the wcserr struct.
     if (linp->err) {
-      ilinp = (int *)(linp->err);
-      for (l = 0; l < ERRLEN; l++) {
+      const int *ilinp = (int *)(linp->err);
+      for (size_t l = 0; l < ERRLEN; l++) {
         *(ivalp++) = *(ilinp++);
       }
     } else {
-      for (l = 0; l < ERRLEN; l++) {
+      for (size_t l = 0; l < ERRLEN; l++) {
         *(ivalp++) = 0;
       }
     }
@@ -321,6 +318,14 @@ int linsize_(const int *lin, int sizes[2])
 
 //----------------------------------------------------------------------------
 
+int linenq_(const int *lin, int *enquiry)
+
+{
+  return linenq((const struct linprm *)lin, *enquiry);
+}
+
+//----------------------------------------------------------------------------
+
 int linprt_(const int *lin)
 
 {
@@ -340,13 +345,12 @@ int linprt_(const int *lin)
 int linperr_(int *lin, const char prefix[72])
 
 {
-  char prefix_[73];
-  wcsutil_strcvt(72, '\0', 1, prefix, prefix_);
-
   // This may or may not force the Fortran I/O buffers to be flushed.
   // If not, try CALL FLUSH(6) before calling LINPERR in the Fortran code.
   fflush(NULL);
 
+  char prefix_[73];
+  wcsutil_strcvt(72, '\0', 1, prefix, prefix_);
   return linperr((struct linprm *)lin, prefix_);
 }
 
