@@ -1,6 +1,6 @@
 /*============================================================================
-  WCSLIB 8.2 - an implementation of the FITS WCS standard.
-  Copyright (C) 1995-2023, Mark Calabretta
+  WCSLIB 8.3 - an implementation of the FITS WCS standard.
+  Copyright (C) 1995-2024, Mark Calabretta
 
   This file is part of WCSLIB.
 
@@ -19,7 +19,7 @@
 
   Author: Mark Calabretta, Australia Telescope National Facility, CSIRO.
   http://www.atnf.csiro.au/people/Mark.Calabretta
-  $Id: prj_f.c,v 8.2.1.1 2023/11/16 10:05:58 mcalabre Exp mcalabre $
+  $Id: prj_f.c,v 8.3 2024/05/13 16:33:01 mcalabre Exp $
 *===========================================================================*/
 
 #include <stdio.h>
@@ -43,10 +43,22 @@
 #define prjini_  F77_FUNC(prjini,  PRJINI)
 #define prjfree_ F77_FUNC(prjfree, PRJFREE)
 #define prjsize_ F77_FUNC(prjsize, PRJSIZE)
+#define prjenq_  F77_FUNC(prjenq,  PRJENQ)
 #define prjprt_  F77_FUNC(prjprt,  PRJPRT)
 #define prjperr_ F77_FUNC(prjperr, PRJPERR)
 #define prjbchk_ F77_FUNC(prjbchk, PRJBCHK)
 
+#ifdef BINDC
+  #undef  prjptc_
+  #define prjptc_ prjptc_c
+
+  #undef  prjgtc_
+  #define prjgtc_ prjgtc_c
+
+  #undef  prjperr_
+  #define prjperr_ prjperr_c
+#endif
+
 // Must match the values set in prj.inc.
 #define PRJ_FLAG      100
 #define PRJ_CODE      101
@@ -75,16 +87,15 @@
 int prjput_(int *prj, const int *what, const void *value, const int *m)
 
 {
-  const char *cvalp;
-  const int  *ivalp;
-  const double *dvalp;
-  struct prjprm *prjp;
-
   // Cast pointers.
-  prjp  = (struct prjprm *)prj;
-  cvalp = (const char *)value;
-  ivalp = (const int *)value;
-  dvalp = (const double *)value;
+  struct prjprm *prjp = (struct prjprm *)prj;
+  const char   *cvalp = (const char *)value;
+  const int    *ivalp = (const int *)value;
+  const double *dvalp = (const double *)value;
+
+  // Preserve bypass mode.
+  int flag = 0;
+  if (prjp->flag == 1 || prjp->flag < 0) flag = 1;
 
   switch (*what) {
   case PRJ_FLAG:
@@ -94,23 +105,23 @@ int prjput_(int *prj, const int *what, const void *value, const int *m)
     // Only three characters need be given.
     wcsutil_strcvt(3, ' ', 1, cvalp, prjp->code);
     wcsutil_null_fill(4, prjp->code);
-    prjp->flag = 0;
+    prjp->flag = flag;
     break;
   case PRJ_R0:
     prjp->r0 = *dvalp;
-    prjp->flag = 0;
+    prjp->flag = flag;
     break;
   case PRJ_PV:
     prjp->pv[*m] = *dvalp;
-    prjp->flag = 0;
+    prjp->flag = flag;
     break;
   case PRJ_PHI0:
     prjp->phi0 = *dvalp;
-    prjp->flag = 0;
+    prjp->flag = flag;
     break;
   case PRJ_THETA0:
     prjp->theta0 = *dvalp;
-    prjp->flag = 0;
+    prjp->flag = flag;
     break;
   case PRJ_BOUNDS:
     prjp->bounds = *ivalp;
@@ -142,19 +153,12 @@ int prjpti_(int *prj, const int *what, const int *value, const int *m)
 int prjget_(const int *prj, const int *what, void *value)
 
 {
-  unsigned int l;
-  int  m;
-  char *cvalp;
-  int  *ivalp;
-  double *dvalp;
-  const int *iprjp;
-  const struct prjprm *prjp;
 
   // Cast pointers.
-  prjp  = (const struct prjprm *)prj;
-  cvalp = (char *)value;
-  ivalp = (int *)value;
-  dvalp = (double *)value;
+  const struct prjprm *prjp = (const struct prjprm *)prj;
+  char   *cvalp = (char *)value;
+  int    *ivalp = (int *)value;
+  double *dvalp = (double *)value;
 
   switch (*what) {
   case PRJ_FLAG:
@@ -167,7 +171,7 @@ int prjget_(const int *prj, const int *what, void *value)
     *dvalp = prjp->r0;
     break;
   case PRJ_PV:
-    for (m = 0; m < PVN; m++) {
+    for (int m = 0; m < PVN; m++) {
       *(dvalp++) = prjp->pv[m];
     }
     break;
@@ -213,18 +217,18 @@ int prjget_(const int *prj, const int *what, void *value)
   case PRJ_ERR:
     // Copy the contents of the wcserr struct.
     if (prjp->err) {
-      iprjp = (int *)(prjp->err);
-      for (l = 0; l < ERRLEN; l++) {
+      const int *iprjp = (int *)(prjp->err);
+      for (size_t l = 0; l < ERRLEN; l++) {
         *(ivalp++) = *(iprjp++);
       }
     } else {
-      for (l = 0; l < ERRLEN; l++) {
+      for (size_t l = 0; l < ERRLEN; l++) {
         *(ivalp++) = 0;
       }
     }
     break;
   case PRJ_W:
-    for (m = 0; m < 10; m++) {
+    for (int m = 0; m < 10; m++) {
       *(dvalp++) = prjp->w[m];
     }
     break;
@@ -279,6 +283,14 @@ int prjsize_(const int *prj, int sizes[2])
 
 //----------------------------------------------------------------------------
 
+int prjenq_(const int *prj, int *enquiry)
+
+{
+  return prjenq((const struct prjprm *)prj, *enquiry);
+}
+
+//----------------------------------------------------------------------------
+
 int prjprt_(const int *prj)
 
 {
@@ -298,13 +310,12 @@ int prjprt_(const int *prj)
 int prjperr_(int *prj, const char prefix[72])
 
 {
-  char prefix_[73];
-  wcsutil_strcvt(72, '\0', 1, prefix, prefix_);
-
   // This may or may not force the Fortran I/O buffers to be flushed.
   // If not, try CALL FLUSH(6) before calling PRJPERR in the Fortran code.
   fflush(NULL);
 
+  char prefix_[73];
+  wcsutil_strcvt(72, '\0', 1, prefix, prefix_);
   return wcserr_prt(((struct prjprm *)prj)->err, prefix_);
 }
 
