@@ -1,6 +1,6 @@
 /*============================================================================
-  WCSLIB 8.1 - an implementation of the FITS WCS standard.
-  Copyright (C) 1995-2023, Mark Calabretta
+  WCSLIB 8.3 - an implementation of the FITS WCS standard.
+  Copyright (C) 1995-2024, Mark Calabretta
 
   This file is part of WCSLIB.
 
@@ -19,7 +19,7 @@
 
   Author: Mark Calabretta, Australia Telescope National Facility, CSIRO.
   http://www.atnf.csiro.au/people/Mark.Calabretta
-  $Id: wcserr_f.c,v 8.1 2023/07/05 17:12:07 mcalabre Exp $
+  $Id: wcserr_f.c,v 8.3 2024/05/13 16:33:01 mcalabre Exp $
 *===========================================================================*/
 
 #include <stdio.h>
@@ -39,6 +39,14 @@
 #define wcserr_prt_     F77_FUNC(wcserr_prt, WCSERR_PRT)
 #define wcserr_clear_   F77_FUNC(wcserr_clear, WCSERR_CLEAR)
 
+#ifdef BINDC
+  #undef  wcserr_gtc_
+  #define wcserr_gtc_ wcserr_gtc_c
+
+  #undef  wcserr_prt_
+  #define wcserr_prt_ wcserr_prt_c
+#endif
+
 // Must match the values set in wcserr.inc.
 #define WCSERR_STATUS   200
 #define WCSERR_LINE_NO  201
@@ -90,14 +98,14 @@ int wcserr_get_(const int *err, const int *what, void *value)
   return 0;
 }
 
-int wcserr_gtc_(const int *wcs, const int *what, char *value)
+int wcserr_gtc_(const int *err, const int *what, char *value)
 {
-  return wcserr_get_(wcs, what, value);
+  return wcserr_get_(err, what, value);
 }
 
-int wcserr_gti_(const int *wcs, const int *what, int *value)
+int wcserr_gti_(const int *err, const int *what, int *value)
 {
-  return wcserr_get_(wcs, what, value);
+  return wcserr_get_(err, what, value);
 }
 
 //----------------------------------------------------------------------------
