@@ -1,6 +1,6 @@
 /*============================================================================
-  PGSBOX 8.2 - draw curvilinear coordinate axes for PGPLOT.
-  Copyright (C) 1997-2023, Mark Calabretta
+  PGSBOX 8.3 - draw curvilinear coordinate axes for PGPLOT.
+  Copyright (C) 1997-2024, Mark Calabretta
 
   This file is part of PGSBOX.
 
@@ -19,7 +19,7 @@
 
   Author: Mark Calabretta, Australia Telescope National Facility, CSIRO.
   http://www.atnf.csiro.au/people/Mark.Calabretta
-  $Id: cpgsbox.c,v 8.2.1.1 2023/11/16 10:05:59 mcalabre Exp mcalabre $
+  $Id: cpgsbox.c,v 8.3 2024/05/13 16:33:01 mcalabre Exp $
 *===========================================================================*/
 
 #include <string.h>
@@ -30,6 +30,14 @@
 #define pgsbok_ F77_FUNC(pgsbok, PGSBOK)
 #define pglbok_ F77_FUNC(pglbok, PGLBOK)
 
+#ifdef BINDC
+  #undef  pgsbok_
+  #define pgsbok_ pgsbok_c
+
+  #undef  pglbok_
+  #define pglbok_ pglbok_c
+#endif
+
 void pgsbok_(const float blc[2], const float trc[2], char idents[3][80],
              const char opt[2], const int *labctl, const int *labden,
              const int ci[7], const int gcode[2], const double *tiklen,
