@@ -1,7 +1,7 @@
 *=======================================================================
 *
-* PGSBOX 7.12 - draw curvilinear coordinate axes for PGPLOT.
-* Copyright (C) 1997-2022, Mark Calabretta
+* PGSBOX 8.3 - draw curvilinear coordinate axes for PGPLOT.
+* Copyright (C) 1997-2024, Mark Calabretta
 *
 * This file is part of PGSBOX.
 *
@@ -20,7 +20,7 @@
 *
 * Author: Mark Calabretta, Australia Telescope National Facility, CSIRO.
 * http://www.atnf.csiro.au/people/Mark.Calabretta
-* $Id: pgtest.f,v 7.12 2022/09/09 04:57:58 mcalabre Exp $
+* $Id: pgtest.f,v 8.3 2024/05/13 16:33:01 mcalabre Exp $
 *=======================================================================
       PROGRAM PGTEST
 *=======================================================================
@@ -160,7 +160,7 @@
       GRID1(0) = 0D0
       GRID2(0) = 0D0
       CALL PGSBOX (BLC, TRC, IDENTS, OPT, -1, 0, C0, GCODE, 2D0,
-     :  0, GRID1, 0, GRID2, .FALSE., LNGVEL, 1, 1, 7, ' ', 0,
+     :  0, GRID1, 0, GRID2, .FALSE., LNGVEL, 1, 1, 7, ' ', NLIPRM,
      :  NLDPRM, 256, IC, CACHE, IERR)
 
 *     Draw fiducial grid lines in white and do labelling.
@@ -170,13 +170,13 @@
       GRID1(1) = 180D0
       GRID2(1) = 0D0
       CALL PGSBOX (BLC, TRC, IDENTS, OPT, 0, 0, C0, GCODE, 0D0,
-     :  1, GRID1, 1, GRID2, .FALSE., LNGVEL, 1, 1, 7, ' ', 0,
+     :  1, GRID1, 1, GRID2, .FALSE., LNGVEL, 1, 1, 7, ' ', NLIPRM,
      :  NLDPRM, 256, IC, CACHE, IERR)
 
 *     Draw the frame.
       CALL PGBOX ('BC', 0.0, 0, 'BC', 0.0, 0)
 
-
+      CALL WCSLEEP (250)
       CALL PGPAGE ()
 
 *-----------------------------------------------------------------------
@@ -238,12 +238,13 @@
       GRID1(0) = 0D0
       GRID2(0) = 0D0
       CALL PGSBOX (BLC, TRC, IDENTS, OPT, 0, 9900, C0, GCODE, 2D0,
-     :  0, GRID1, 0, GRID2, .FALSE., FSCAN, 1, 1, 7, ' ', 0,
+     :  0, GRID1, 0, GRID2, .FALSE., FSCAN, 1, 1, 7, ' ', NLIPRM,
      :  NLDPRM, 256, IC, CACHE, IERR)
 
 *     Draw the frame.
       CALL PGBOX ('BC', 0.0, 0, 'BC', 0.0, 0)
 
+      CALL WCSLEEP (250)
       CALL PGPAGE ()
 
 *-----------------------------------------------------------------------
@@ -302,6 +303,7 @@
 *     Draw the frame.
       CALL PGBOX ('BC', 0.0, 0, 'BC', 0.0, 0)
 
+      CALL WCSLEEP (250)
       CALL PGPAGE ()
 
 *-----------------------------------------------------------------------
@@ -383,6 +385,7 @@
 *     Draw the frame.
       CALL PGBOX ('BC', 0.0, 0, 'BC', 0.0, 0)
 
+      CALL WCSLEEP (250)
       CALL PGPAGE ()
 
 *-----------------------------------------------------------------------
@@ -503,6 +506,7 @@
       CALL PGSCI (1)
       CALL PGBOX ('BC', 0.0, 0, 'BC', 0.0, 0)
 
+      CALL WCSLEEP (250)
       CALL PGPAGE ()
 
 *-----------------------------------------------------------------------
@@ -715,6 +719,7 @@
       CALL PGSCI (1)
       CALL PGBOX ('BC', 0.0, 0, 'BC', 0.0, 0)
 
+      CALL WCSLEEP (250)
       CALL PGPAGE ()
 
 *-----------------------------------------------------------------------
@@ -878,6 +883,7 @@
       CALL PGSCI (1)
       CALL PGBOX ('BC', 0.0, 0, 'BC', 0.0, 0)
 
+      CALL WCSLEEP (250)
       CALL PGPAGE ()
 
 *-----------------------------------------------------------------------
@@ -955,6 +961,7 @@
 *     Draw the frame.
       CALL PGBOX ('BC', 0.0, 0, 'BC', 0.0, 0)
 
+      CALL WCSLEEP (250)
       CALL PGPAGE ()
 
 *-----------------------------------------------------------------------
@@ -1036,6 +1043,7 @@
 *     Draw the frame.
       CALL PGBOX ('BC', 0.0, 0, 'BC', 0.0, 0)
 
+      CALL WCSLEEP (250)
       CALL PGPAGE ()
 
 *-----------------------------------------------------------------------
@@ -1113,6 +1121,7 @@
 *     Draw the frame.
       CALL PGBOX ('BC', 0.0, 0, 'BC', 0.0, 0)
 
+      CALL WCSLEEP (250)
       CALL PGPAGE ()
 
 *-----------------------------------------------------------------------
@@ -1243,6 +1252,7 @@
 *     Draw the frame.
       CALL PGBOX ('BC', 0.0, 0, 'BC', 0.0, 0)
 
+      CALL WCSLEEP (250)
       CALL PGPAGE ()
 
 *-----------------------------------------------------------------------
@@ -1283,6 +1293,7 @@
 *     Draw the frame.
       CALL PGBOX ('BC', 0.0, 0, 'BC', 0.0, 0)
 
+      CALL WCSLEEP (250)
       CALL PGPAGE ()
 
 *-----------------------------------------------------------------------
@@ -1350,6 +1361,7 @@
 *     Draw the frame.
       CALL PGBOX ('BC', 0.0, 0, 'BC', 0.0, 0)
 
+      CALL WCSLEEP (250)
       CALL PGPAGE ()
 
 *-----------------------------------------------------------------------
